GeoJsonFeature<T extends GeoJsonGeometry> class

Annotations
  • @JsonSerializable.new(genericArgumentFactories: true)

Constructors

GeoJsonFeature({required T geometry, Map<String, dynamic>? properties, List<double>? boundingBox, dynamic type})
GeoJsonFeature.fromJson(Map<String, dynamic> json)
factory

Properties

boundingBox → List<double>?
Bounding box
final
geometry → T
The feature geo data
final
hashCode → int
The hash code for this object.
no setteroverride
properties → Map<String, dynamic>?
The feature properties
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → GeoJsonType
The type of the feature
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
override