GeoJsonQuery class

A geojson query for search

Constructors

GeoJsonQuery({String? property, dynamic value, GeoJsonGeometryType? geometryType, bool matchCase = true, GeoSearchType searchType = GeoSearchType.exact})
Provide a geometryType and/or a property and value

Properties

geometryType → GeoJsonGeometryType?
The type of geometry to search for
final
hashCode → int
The hash code for this object.
no setterinherited
matchCase → bool
Match the case of string or not
final
property → String?
The property to search for
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchType → GeoSearchType
The type of search to process (for strings)
final
value → dynamic
The value of the property to search for
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited